@@ -5,7 +5,7 @@
     Contact ........ jimmy@advcs.org
     Home Site ...... http://www.advcs.org/
     Program ........ Archive Mail
-    Version ........ 1.1
+    Version ........ 1.2
     Purpose ........ Allows you to download your email in a compressed archive
 
 *******************************************************************************/
@@ -14,7 +14,8 @@
    global $msg, $username, $attachment_dir, $mailbox, $charset,
       $data_dir, $composesession, $uid_support, $sort, $names,
       $msgs, $thread_sort_messages, $allow_server_sort, $show_num,
-      $compose_messages, $startMessage, $imapConnection, $archivetype;
+      $compose_messages, $startMessage, $imapConnection, $archivetype,
+      $SQM_INTERNAL_VERSION;
 
    if (!defined('SM_PATH')) define('SM_PATH','../../../');
 
@@ -45,16 +46,22 @@
    $j = 0;
    $mbox = '';
    $c = 0;
+
    $format = array('separate','eml','mbox','maildir');
    while ($j < count($msg)) {
       if (isset($msg[$i])) {
          $id = $msg[$i];
 
-         $k = $id;
-//         for ($k = 0; $k < count($msgs); $k++) {
-//            if ($msgs[$k]['ID'] == $id)
-//               break;
-//         }
+         if (!isset($SQM_INTERNAL_VERSION) || $SQM_INTERNAL_VERSION[1] != 5) {
+            for ($k = 0; $k < count($msgs); $k++) {
+               if ($msgs[$k]['ID'] == $id) {
+                  break;
+               }
+            }
+         } else {
+            $k = $id;
+         }
+
          include (SM_PATH . 'plugins/archive_mail/includes/formats/' . $format[$archiveent] . '.php');
          $j++;
       }
